==> sparkautomapper-0.2.60.tar.gz: sparkautomapper-0.2.60/spark_auto_mapper/data_types/array_distinct.py <==
from typing import List, Union, TypeVar, Optional

from pyspark.sql import Column, DataFrame
from pyspark.sql.functions import array_distinct

from spark_auto_mapper.data_types.data_type_base import AutoMapperDataTypeBase
from spark_auto_mapper.data_types.text_like_base import AutoMapperTextLikeBase
from spark_auto_mapper.helpers.value_parser import AutoMapperValueParser
from spark_auto_mapper.type_definitions.native_types import AutoMapperNativeSimpleType

_T = TypeVar("_T", bound=Union[AutoMapperNativeSimpleType, AutoMapperDataTypeBase])


class AutoMapperArrayDistinctDataType(AutoMapperTextLikeBase):
    """
    Returns the distinct items in the array. NULL elements are skipped
    """

    def __init__(
        self,
        *args: _T,
    ):
        super().__init__()
        self.value: List[AutoMapperDataTypeBase] = [
            value
            if isinstance(value, AutoMapperDataTypeBase)
            else AutoMapperValueParser.parse_value(value)
            for value in args
        ]

    def get_column_spec(
        self, source_df: Optional[DataFrame], current_column: Optional[Column]
    ) -> Column:
        column_spec = array_distinct(
            *[
                col.get_column_spec(source_df=source_df, current_column=current_column)
                for col in self.value
            ]
        )
        return column_spec

    def include_null_properties(self, include_null_properties: bool) -> None:
        for item in self.value:
            item.include_null_properties(
                include_null_properties=include_null_properties
            )

==> sparkautomapper-1.0.2b1.tar.gz: sparkautomapper-1.0.2b1/spark_auto_mapper/data_types/array_distinct.py <==
from typing import List, Union, TypeVar, Optional

from pyspark.sql import Column, DataFrame
from pyspark.sql.functions import array_distinct

from spark_auto_mapper.data_types.data_type_base import AutoMapperDataTypeBase
from spark_auto_mapper.data_types.text_like_base import AutoMapperTextLikeBase
from spark_auto_mapper.helpers.value_parser import AutoMapperValueParser
from spark_auto_mapper.type_definitions.native_types import AutoMapperNativeSimpleType

_T = TypeVar("_T", bound=Union[AutoMapperNativeSimpleType, AutoMapperDataTypeBase])


class AutoMapperArrayDistinctDataType(AutoMapperTextLikeBase):
    """
    Returns the distinct items in the array. NULL elements are skipped
    """

    def __init__(
        self,
        *args: _T,
    ):
        super().__init__()
        self.value: List[AutoMapperDataTypeBase] = [
            value
            if isinstance(value, AutoMapperDataTypeBase)
            else AutoMapperValueParser.parse_value(value)
            for value in args
        ]

    def get_column_spec(
        self, source_df: Optional[DataFrame], current_column: Optional[Column]
    ) -> Column:
        column_spec = array_distinct(
            *[
                col.get_column_spec(source_df=source_df, current_column=current_column)
                for col in self.value
            ]
        )
        return column_spec

    def include_null_properties(self, include_null_properties: bool) -> None:
        for item in self.value:
            item.include_null_properties(
                include_null_properties=include_null_properties
            )

    @property
    def children(
        self,
    ) -> Union[AutoMapperDataTypeBase, List[AutoMapperDataTypeBase]]:
        return self.value
